//
//  ViewController.swift
//  Notify
//
//  Created by Mark Meretzky on 11/22/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit;
import AVFoundation;	//for AVAudioPlayer

class ViewController: UIViewController {
	let names: [String] = [
		"Beatles", //"She Loves You" (portrait)
		"Stones"   //"Satisfaction" (landscape)
	];
	var players: [AVAudioPlayer] = [AVAudioPlayer]();	//empty array of AVAudioPlayers

	override func viewDidLoad() {
		super.viewDidLoad()
		// Do any additional setup after loading the view, typically from a nib.
		(view as UILabel).textAlignment = NSTextAlignment.Center;
		let bundle: NSBundle = NSBundle.mainBundle();

		for name in names {
			let pathName: String = bundle.pathForResource(name, ofType: "mp3")!;
			let url: NSURL = NSURL(fileURLWithPath: pathName, isDirectory: false)!;
			let player: AVAudioPlayer = AVAudioPlayer(contentsOfURL: url, error: nil);
			player.numberOfLoops = -1;	//infinite loop
			player.prepareToPlay();
			players.append(player);
		}

		/*
		Whenever the device sends out a UIDeviceOrientationDidChangeNotification,
		the notification center will carry the notification to the
		deviceOrientationDidChange method of self.  (self is this view controller.)
		*/

		let notificationCenter: NSNotificationCenter = NSNotificationCenter.defaultCenter();
		let device: UIDevice = UIDevice.currentDevice();

		notificationCenter.addObserver(self,
			selector: "deviceOrientationDidChange:",
			name: UIDeviceOrientationDidChangeNotification,
			object: device);
	}

	//Called when the orientation of the device changes.
	//No need to call prepareToPlay again after a pause.

	func deviceOrientationDidChange(notification: NSNotification) {
		let device: UIDevice = UIDevice.currentDevice();
		let orientation = device.orientation;
		let label: UILabel = view as UILabel;	//Downcast UIView to UILabel.

		if orientation == UIDeviceOrientation.Portrait
			|| orientation == UIDeviceOrientation.PortraitUpsideDown {
			label.text = "Portrait: the Beatles";
			players[1].pause();	//Pause the Rolling Stones.
			players[0].play();	//Play the Beatles.
		} else {
			label.text = "Landscape: the Rolling Stones";
			players[0].pause();	//Pause the Beatles.
			players[1].play();	//Play the Rolling Stones.
		}
	}

	override func didReceiveMemoryWarning() {
		super.didReceiveMemoryWarning()
		// Dispose of any resources that can be recreated.
	}


}

